# eldar_text_art

A fun and creative text & emoji art library created by Eldar Eliyev.

## Installation
pip install eldar_text_art

## Usage
import eldar_text_art as eta

print(eta.create_banner('Eldar'))
